# This file contains examples that show how to create
# a chart using the J4L-chart API

require 'rubygems'

require 'chart_loader.rb'
require 'chart_image.rb'
require 'chart_graphics.rb'
require 'graphics_provider.rb'


class Chart_Examples

  attr_accessor   :imagesDir

  def initialize
    @imagesDir="";
  end


  
	#
	# line 3D example
	# @return
	#
  def example9()

    # data
    d1=[1,1,3,3.5,5,4,2]
    d2=[2,2,5,6,5.4,3.5,3.1]

    # series
    data1= J4LChart::LineDataSerie.new(J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),J4LChart::LINE_NORMAL),d1)
    data1.drawPoint=false
    data1.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,11)
    data2= J4LChart::LineDataSerie.new(J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN),J4LChart::LINE_NORMAL),d2)
    data2.drawPoint=false
    data2.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,11)
    data2.fillStyle=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN))

    # legend
    l=J4LChart::Legend.new()
    l.addItem("Products",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE)))
    l.addItem("Services",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)))

    # create title
    title=J4LChart::Title.new("Sales (thousands $)")
    # create axis

    xAxis=J4LChart::Axis.new(J4LChart::HORIZONTAL,J4LChart::Scale.new())
    yAxis=J4LChart::Axis.new(J4LChart::VERTICAL,J4LChart::Scale.new())
    xAxis.tickAtBase=true # draw also first tick
    xAxis.scale.min=0
    yAxis.scale.min=0
    yAxis.scaleTickInterval=1
    xAxis.scaleTickInterval=1
    yAxis.bigTickInterval=2
    yAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::GRAY),J4LChart::LINE_NORMAL)
    lbls=["June","July","Aug.","Sept.","Oct.","Nov.","Dec."]
    xAxis.tickLabels=lbls


    xLabel= J4LChart::HAxisLabel.new("",J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,14))
    yLabel= J4LChart::VAxisLabel.new("Brutto",J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,14))

    # plotter
    plot=J4LChart::LinePlotter3D.new()

    # create report
    chart=J4LChart::Chart.new()
    chart.resetChart(title,plot,xAxis,yAxis)
    plot.border=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
    plot.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE))
    chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW))
    chart.back.colorFrom=J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW)
    chart.back.colorUntil=J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE)
    chart.back.gradientType=J4LChart::GRADIENT_HORIZONTAL
    chart.xLabel=xLabel
    chart.yLabel=yLabel
    chart.legend=l
    chart.addSerie(data2)
    chart.addSerie(data1)

    return chart


  end

	#
	# bar 3D example
	# @return
	#
	def example8()

    # data
    d1=[1,2,1,4,5,4,2]
    data1= J4LChart::BarDataSerie.new(J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::ORANGE)),d1)
    data1.borderType=J4LChart::BORDER_RAISED
    data1.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)

    d2=[-1,3,4,4.2,6.4,4.5,6.1]
    data2=  J4LChart::BarDataSerie.new(J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)),d2)
    data2.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)
    data2.borderType=J4LChart::BORDER_RAISED
    data2.negativeStyle=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::RED))


    l=J4LChart::Legend.new()
    l.border=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
    l.addItem("Company A",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::ORANGE)))
    l.addItem("Company B",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)))
    l.background=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::LIGHTGRAY))

    # create title
    title=J4LChart::Title.new("Benefits companies A & B")
    # create axis
    xAxis=J4LChart::Axis.new(J4LChart::HORIZONTAL,J4LChart::Scale.new())
    yAxis=J4LChart::Axis.new(J4LChart::VERTICAL,J4LChart::Scale.new())
    y2Axis=J4LChart::Axis.new(J4LChart::VERTICAL,J4LChart::Scale.new())

    xAxis.tickAtBase=true # draw also first tick
    xAxis.scale.min=0
    xAxis.scale.max=7
    yAxis.scale.min=-2
    yAxis.scale.max=7
    yAxis.integerScale=true

    y2Axis.scale.min=-2
    y2Axis.scale.max=7
    y2Axis.integerScale=true
    y2Axis.scaleTickInterval=1

    yAxis.scaleTickInterval=1
    xAxis.scaleTickInterval=1
    xAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::LIGHTGRAY),J4LChart::LINE_DOTS)
    yAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::LIGHTGRAY),J4LChart::LINE_DOTS)
    lbls=["1992","1993","1994","1995","1996","1997","1998","1999"]
    xAxis.tickLabels=lbls

    xLabel= J4LChart::HAxisLabel.new("Year",J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,12))
    yLabel= J4LChart::VAxisLabel.new("million $",J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,12))
    yLabel.vertical=true

    # plotter
    plot=J4LChart::BarPlotter3D.new()
    # create report
    chart=J4LChart::Chart.new()
    chart.resetChart(title,plot,xAxis,yAxis)
    plot.interBarSpace=1
    plot.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE))
    plot.depth=20
    plot.fullDepth=true

    chart.xLabel=xLabel
    chart.yLabel=yLabel
    chart.legend=l
    chart.addSerie(data2)
    chart.addSerie(data1)
    chart.legendMargin=0.25
    chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW))

    chart.backImage=J4LChart::GraphicsProvider.getimagefromfile(@imagesDir+"back13.gif")

    return chart


  end

  #
  # bubble chart example
  # @return
  #
  def example13()

    # first

    # data
    d1=[2,1 ,2 ,3 ,4 ,5 ,4 ,3]
    dmax1=[0.5,0 ,0.2 ,0.1 ,0.5 ,0,1 ,0]
    data1=  J4LChart::MaxMinDataSerie.new(nil,d1)
    data1.bubbleChart=true
    data1.fillBubble=true
    data1.drawPoint=true
    data1.pointColor=J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)
    data1.setMaxMinValues(dmax1,nil)

    d2=[2,1 ,2 ,3 ,4 ,5 ,4 ,3]
    data2= J4LChart::LineDataSerie.new(J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_DOTS),d2)
    data2.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)
    data2.valueColor=J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW)
    data2.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)

    # second

    d3=[1,2 ,3 ,2 ,3 ,4 ,1 ,2]
    dmax3=[0,0.2 ,0.2 ,0 ,0.2 ,0,0.3 ,0]
    data3=  J4LChart::MaxMinDataSerie.new(nil,d3)
    data3.bubbleChart=true
    data3.fillBubble=false
    data3.drawPoint=true
    data3.pointColor=J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE)
    data3.setMaxMinValues(dmax3,nil)

    d4=[1,2 ,3 ,2 ,3 ,4 ,1 ,2]
    data4= J4LChart::LineDataSerie.new(J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_DOTS),d4)
    data4.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)
    data4.valueColor=J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW)
    data4.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)

    # create title
    title=J4LChart::Title.new("Price")
    title.color=J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE)

    # create axis
    xAxis=J4LChart::Axis.new(J4LChart::HORIZONTAL,J4LChart::Scale.new())
    yAxis=J4LChart::Axis.new(J4LChart::VERTICAL,J4LChart::Scale.new())
    xAxis.tickAtBase=true # draw also first tick
    xAxis.scale.min=-1
    xAxis.ceroAxis=J4LChart::CEROAXIS_NO
    yAxis.ceroAxis=J4LChart::CEROAXIS_NO
    yAxis.scale.min=0
    yAxis.scale.max=6
    yAxis.descColor=J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE)
    yAxis.scaleTickInterval=1
    xAxis.scaleTickInterval=1
    xAxis.bigTickInterval=1
    xAxis.descColor=J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE)
    lbls=[" ","8 Jan.","9 Jan.","10 Jan.","11 Jan.","12 Jan.","13 Jan.","14 Jan.","15 Jan."]
    xAxis.tickLabels=lbls
    xAxis.style =J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_NORMAL)
    yAxis.style =J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_NORMAL)

    xLabel= J4LChart::HAxisLabel.new("Week",J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,12))
    yLabel= J4LChart::VAxisLabel.new("Value",J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,12))

    # plotter
    plot=J4LChart::LinePlotter.new()

    # create report
    chart=J4LChart::Chart.new()
    chart.resetChart(title,plot,xAxis,yAxis)
    chart.xLabel=xLabel
    chart.yLabel=yLabel
    chart.addSerie(data1)
    chart.addSerie(data2)

    chart.addSerie(data4)
    chart.addSerie(data3)
    chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE))


    return chart

  end


	#
  # Pie chart example
  # @return
  #
  def example3()

    d1=[9918,22652,511,36811]
    # style of the pie
    s1=Array.new(4)
    s1[0]=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::CYAN));
    s1[1]=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE));
    s1[2]=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN));
    s1[3]=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW));
    data1= J4LChart::PieDataSerie.new(d1,s1)
    data1.textDistanceToCenter=1.2
    data1.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::BOLD,13)
    data1.textDistanceToCenter=1.1

    # legend
    l=J4LChart::Legend.new()
    l.background=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::LIGHTGRAY))
    l.border=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
    l.addItem("Software",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE)))
    l.addItem("Hardware",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)))
    l.addItem("Services",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW)))
    l.addItem("Other 1",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::CYAN)))


    # create title
    title=J4LChart::Title.new("Sales 2005")

    # plotter
    plot= J4LChart::PiePlotter.new()
    plot.radiusModifier=0.6

    plot.labelLine=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)

		# create chart
    chart=J4LChart::Chart.new()
    chart.resetChart(title,plot,nil,nil)
    # chart background
    chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::DARKGRAY))
    chart.back.gradientType=J4LChart::GRADIENT_VERTICAL
    # add legend
    chart.legend=l
    # add data
    chart.addSerie(data1)


    chart.backImage=J4LChart::GraphicsProvider.getimagefromfile(@imagesDir+"back16.gif")

    return chart

  end


	#
	# Pie chart 3D example
	# @return
	#
	def example4()
	  # data
    d1=[34,34,34,34,34]
    b1=Array.new(4)
    b1[0]=true
    b1[1]=false
    b1[2]=true
    b1[3]=true

    labels=["Software","Hardware","Services","Other"]
    # style of the pie
    s1=[J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::CYAN)),J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE)),J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)),J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW)),J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::RED))]
    data1= J4LChart::PieDataSerie.new(d1,s1,b1,labels)
    data1.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,14)

    # legend
    l=J4LChart::Legend.new()
    l.background=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::LIGHTGRAY))
    l.border=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
    l.addItem(labels[0],J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE)))
    l.addItem(labels[1],J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)))
    l.addItem(labels[2],J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW)))
    l.addItem(labels[3],J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::CYAN)))
    l.addItem(labels[3],J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)))

    # create title
    title=J4LChart::Title.new("Sales 2005")

    # plotter
    plot=J4LChart::PiePlotter.new()
    # 3D effect
    plot.effect3D=true
    plot.border=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)

    data1.textDistanceToCenter=0.3
    plot.labelFormat="#PERCENTAGE#"

    # create chart
    chart=J4LChart::Chart.new()
    chart.resetChart(title,plot,nil,nil)
    # chart background
    chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::DARKGRAY))
    chart.back.gradientType=J4LChart::GRADIENT_VERTICAL

    # add legend
    chart.legend=l
    # legend position and layout
    chart.layout=J4LChart::LAYOUT_LEGEND_BOTTOM
    chart.bottomMargin=0
    chart.topMargin=0.2 # 20%
    l.verticalLayout=false
    # add data
    chart.addSerie(data1)

    chart.backImage=J4LChart::GraphicsProvider.getimagefromfile(@imagesDir+"back16.gif")

    return chart

  end

	#
	# bar chart example
  # @return
  #
  def example2()

    # data
    d1=[1,2,3,4,5,4,2]
    data1= J4LChart::BarDataSerie.new(J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::CYAN)),d1)
    data1.border=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
    #
    data1.border=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
    data1.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)

    d2=[-2,3,4,4.2,6.4,4.5,6.1]
    data2= J4LChart::BarDataSerie.new(J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)),d2)
    data2.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)
    data2.border=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
    data2.negativeStyle=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::RED))

    l=J4LChart::Legend.new()
    l.border=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
    l.addItem("Company A",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::CYAN)))
    l.addItem("Company B",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)))

    # create title
    title=J4LChart::Title.new("Benefits companies A & B")
    # create axis
    xAxis=J4LChart::Axis.new(J4LChart::HORIZONTAL,J4LChart::Scale.new())
    yAxis=J4LChart::Axis.new(J4LChart::VERTICAL,J4LChart::Scale.new())
    xAxis.tickAtBase=true # draw also first tick
    xAxis.scale.min=-3
    xAxis.scale.max=7
    yAxis.scale.min=0
    yAxis.scale.max=7
    yAxis.integerScale=true
    yAxis.scaleTickInterval=1
    xAxis.scaleTickInterval=1
    xAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_DOTS)
    yAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_DOTS)
    lbls=["1999","2000","2001","2002","2003","2004","2005","2006"]
    yAxis.tickLabels=lbls

    xLabel= J4LChart::HAxisLabel.new("million $",J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,12))
    yLabel= J4LChart::VAxisLabel.new("Year",J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,12))
    yLabel.vertical=true

    # plotter
    plot=J4LChart::BarPlotter.new()
    plot.verticalBars=false
    plot.interBarSpace=0

    # create report
    chart=J4LChart::Chart.new()
    chart.resetChart(title,plot,xAxis,yAxis)
    chart.xLabel=xLabel
    chart.yLabel=yLabel
    chart.legend=l
    chart.addSerie(data2)
    chart.addSerie(data1)
    chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::LIGHTGRAY))



    return chart

  end

  #
  # Line chart example
  # @return
  #
  def example1()

    #data
    d1=[1,0,3,4,5,4,2]
    d2=[3,8,4,3,0,9,6.100002]

    # series
    data1= J4LChart::LineDataSerie.new(J4LChart::LineStyle.new(2,J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),J4LChart::LINE_NORMAL),d1)
    data1.drawPoint=true
    data1.valueFormat="%.1d"
    data1.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)
    data2= J4LChart::LineDataSerie.new(J4LChart::LineStyle.new(2,J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN),J4LChart::LINE_NORMAL),d2)
    data2.drawPoint=true

    data2.fillStyle=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),0.5 )
    data2.valueFormat="%.1d"
    data2.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)

    # legend
    l=J4LChart::Legend.new()
    l.background=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE))
    l.border=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
    l.addItem("Products",J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),J4LChart::LINE_NORMAL))
    l.addItem("Services",J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN),J4LChart::LINE_NORMAL))


    # create title
    title=J4LChart::Title.new("Sales (thousands $)")
    # create axis
    xAxis=J4LChart::Axis.new(J4LChart::HORIZONTAL,J4LChart::Scale.new())
    yAxis=J4LChart::Axis.new(J4LChart::VERTICAL,J4LChart::Scale.new())
    xAxis.tickAtBase=true # draw also first tick
    xAxis.scale.min=0
    yAxis.scale.min=0
    yAxis.scale.max=7
    yAxis.scaleTickInterval=1
    xAxis.scaleTickInterval=1
    xAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_DOTS)
    yAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_DOTS)
    lbls=["June","July","Aug.","Sept.","Oct.","Nov.","Dec."]
    xAxis.tickLabels=lbls


    xLabel= J4LChart::HAxisLabel.new("Date",J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,14))
    yLabel= J4LChart::VAxisLabel.new("Brutto",J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,14))
    yLabel.vertical=true

    # plotter
    plot=J4LChart::LinePlotter.new()
    plot.fixedLimits=true

    #create report
    chart=J4LChart::Chart.new()
    chart.resetChart(title,plot,xAxis,yAxis)
    chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::RED))
    chart.back.gradientType=J4LChart::GRADIENT_HORIZONTAL
    chart.xLabel=xLabel
    chart.yLabel=yLabel
    chart.legend=l
    chart.addSerie(data2)
    chart.addSerie(data1)

    return chart
  end


	#
	# Radar chart (transparent filling) example
	# @return
  #
  def example12()

    # data
    d1=[1,2,3,4,5]
    d2=[2,3,4,4.2,3]

    # series
    data1= J4LChart::LineDataSerie.new(J4LChart::LineStyle.new(2,J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),J4LChart::LINE_NORMAL),d1)
    data1.drawPoint=true
    data1.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)
    data1.fillStyle=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),0.5)

    data2= J4LChart::LineDataSerie.new(J4LChart::LineStyle.new(2,J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN),J4LChart::LINE_NORMAL),d2)
    data2.drawPoint=true
    data2.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)
    data2.fillStyle=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN),0.5)

    # legend
    l=J4LChart::Legend.new()
    l.background=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE))
    l.border=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
    l.addItem("Products",J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),J4LChart::LINE_NORMAL))
    l.addItem("Services",J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN),J4LChart::LINE_NORMAL))

    # create title
    title=J4LChart::Title.new("Sales (thousands $)")

    # plotter
    plot= J4LChart::RadarPlotter.new()

    fMaxs=[6,6,6,6,6]
    fMins=[0,0,0,0,0]
    factors=["factor1","factor2","factor3","factor4","factor5","factor6"]

    plot.factorMaxs=fMaxs
    plot.factorMins=fMins
    plot.factorNames=factors
    plot.backStyle=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW))
    plot.radiusModifier=0.8

    plot.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_DASHED)
    plot.gridFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)

    # create report
    chart=J4LChart::Chart.new()
    chart.resetChart(title,plot,nil,nil)
    chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::RED))
    chart.back.gradientType=J4LChart::GRADIENT_HORIZONTAL
    chart.legend=l
    chart.addSerie(data2)
    chart.addSerie(data1)

    return chart
  end


	#
	# area chart example
	# @return
	#
	def example5()

    # data
    d1=[3,4,3,4,5,4,2]
    d2=[2,3,4,6,6.4,4.5,6.1]

    # series
    data1= J4LChart::LineDataSerie.new(J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL),d1)
    data1.drawPoint=true
    data1.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)
    data1.fillStyle=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),0.5)
    data2= J4LChart::LineDataSerie.new(J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL),d2)
    data2.drawPoint=true
    data2.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)
    data2.fillStyle=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN))

    # legend
    l=J4LChart::Legend.new()
    l.addItem("Products",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE)))
    l.addItem("Services",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)))

    # create title
    title=J4LChart::Title.new("Sales (thousands $)")
    # create axis
    xAxis=J4LChart::Axis.new(J4LChart::HORIZONTAL,J4LChart::Scale.new())
    yAxis=J4LChart::Axis.new(J4LChart::VERTICAL,J4LChart::Scale.new())
    xAxis.tickAtBase=true # draw also first tick
    xAxis.scale.min=0
    yAxis.scale.min=0
    xAxis.autoNumberOfTicks=5
    pti=[0.1,0.5,1,2,3,4,5,7,10,25,50,100,250,500,1000,5000,10000,50000,100000,500000,1000000]
    xAxis.ticks_preferred_Interval=pti

    yAxis.scaleTickInterval=1
    xAxis.scaleTickInterval=1
    yAxis.bigTickInterval=2
    yAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::GRAY),J4LChart::LINE_NORMAL)

    xLabel= J4LChart::HAxisLabel.new("",J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,14))
    yLabel= J4LChart::VAxisLabel.new("Brutto",J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,14))

    # plotter
    plot=J4LChart::LinePlotter.new()

    # create report
    chart=J4LChart::Chart.new()
    chart.resetChart(title,plot,xAxis,yAxis)
    chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW))
    chart.back.colorFrom=J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW)
    chart.back.colorUntil=J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE)
    chart.back.gradientType=J4LChart::GRADIENT_HORIZONTAL
    chart.xLabel=xLabel
    chart.yLabel=yLabel
    chart.legend=l
    chart.addSerie(data2)
    chart.addSerie(data1)

    return chart
  end


	#
	# Column chart example
	# @return
	#
  def example6()

    # data
    d1=[1,2,3,4,5,4,2]
    data1= J4LChart::BarDataSerie.new(J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::ORANGE)),d1)
    data1.borderType=J4LChart::BORDER_RAISED
    data1.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)

    d2=[2,3,4,4.2,6.4,4.5,6.1]
    data2= J4LChart::BarDataSerie.new(J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)),d2)
    data2.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)
    data2.borderType=J4LChart::BORDER_RAISED
    data2.negativeStyle=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::RED))

    l=J4LChart::Legend.new()
    l.border=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
    l.addItem("Company A",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::ORANGE)))
    l.addItem("Company B",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)))
    l.background=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::LIGHTGRAY))

    # create title
    title=J4LChart::Title.new("Benefits companies A & B")
    # create axis
    xAxis=J4LChart::Axis.new(J4LChart::HORIZONTAL,J4LChart::Scale.new())
    yAxis=J4LChart::Axis.new(J4LChart::VERTICAL,J4LChart::Scale.new())
    xAxis.tickAtBase=true # draw also first tick
    xAxis.scale.min=0
    xAxis.scale.max=7
    yAxis.scale.min=0
    yAxis.scale.max=7
    yAxis.integerScale=true
    yAxis.scaleTickInterval=1
    xAxis.scaleTickInterval=1
    xAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_DOTS)
    yAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_DOTS)
    lbls=["1999","2000","2001","2002","2003","2004","2005","2006"]
    xAxis.tickLabels=lbls

    xLabel= J4LChart::HAxisLabel.new("Year",J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,12))
    yLabel= J4LChart::VAxisLabel.new("million $",J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,12))

    # plotter
    plot=J4LChart::BarPlotter.new()
    # create report
    chart=J4LChart::Chart.new()
    chart.resetChart(title,plot,xAxis,yAxis)
    plot.interBarSpace=1
    chart.xLabel=xLabel
    chart.yLabel=yLabel
    chart.legend=l
    chart.addSerie(data2)
    chart.addSerie(data1)
    chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::LIGHTGRAY))
    chart.backImage=J4LChart::GraphicsProvider.getimagefromfile(@imagesDir+"back13.gif")

    return chart

  end

  #
  # stacked bars example
  # @return
  ##/
  def example7()

    # data
    d1=[1,2,3,4,5,4,2]
    data1= J4LChart::BarDataSerie.new(J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE)),d1)
    data1.borderType=J4LChart::BORDER_RAISED

    d2=[2,3,4,1.2,1.4,1.5,3.1]
    data2= J4LChart::BarDataSerie.new(J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::RED)),d2)
    data2.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)
    data2.borderType=J4LChart::BORDER_RAISED


    l=J4LChart::Legend.new()
    l.addItem("Company A",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::RED)))
    l.addItem("Company B",J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE)))

    # create title
    title=J4LChart::Title.new("Benefits companies A + B")
    # create axis
    xAxis=J4LChart::Axis.new(J4LChart::HORIZONTAL,J4LChart::Scale.new())
    yAxis=J4LChart::Axis.new(J4LChart::VERTICAL,J4LChart::Scale.new())
    xAxis.tickAtBase=true # draw also first tick
    xAxis.scale.min=0
    xAxis.scale.max=8
    yAxis.scale.min=0
    yAxis.scale.max=7
    yAxis.integerScale=true
    yAxis.scaleTickInterval=1
    xAxis.scaleTickInterval=1
    xAxis.style=J4LChart::LineStyle.new(2,J4LChart::GraphicsProvider.getcolor(J4LChart::LIGHTGRAY),J4LChart::LINE_NORMAL)
    yAxis.style=J4LChart::LineStyle.new(2,J4LChart::GraphicsProvider.getcolor(J4LChart::LIGHTGRAY),J4LChart::LINE_NORMAL)
    xAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::LIGHTGRAY),J4LChart::LINE_DASHED)
    yAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::LIGHTGRAY),J4LChart::LINE_DASHED)
    lbls=[" ","1999","2000","2001","2002","2003","2004","2005"," "]
    xAxis.tickLabels=lbls

    xLabel= J4LChart::HAxisLabel.new("Year",J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,12))
    yLabel= J4LChart::VAxisLabel.new("million $",J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,12))

    # plotter
    plot=J4LChart::BarPlotter.new()
    # create report
    chart=J4LChart::Chart.new()
    chart.resetChart(title,plot,xAxis,yAxis)
    chart.xLabel=xLabel
    chart.yLabel=yLabel
    chart.legend=l
    chart.addSerie(data2)
    chart.addSerie(data1)
    chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::LIGHTGRAY))
    plot.cumulative=true
    plot.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE))

    return chart
  end

	#
	# Combined lines and bars example
	# @return
	#
  def example10()

    # data
    d1=[1,2,3,4,5,3,4]
    d2=[0,1,2,3,4,5,3,4]

    # series
    data2= J4LChart::LineDataSerie.new(J4LChart::LineStyle.new(2,J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),J4LChart::LINE_NORMAL),d2)
    data2.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)
    data1= J4LChart::BarDataSerie.new(J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::ORANGE)),d1)
    data1.border=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)

    # legend
    l=J4LChart::Legend.new()
    l.background=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE))
    l.border=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
    l.addItem("Products",J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),J4LChart::LINE_NORMAL))
    l.verticalLayout=false

    # create title
    title=J4LChart::Title.new("Sales (thousands $)")
    # create axis
    xAxis=J4LChart::Axis.new(J4LChart::HORIZONTAL,J4LChart::Scale.new())
    yAxis=J4LChart::Axis.new(J4LChart::VERTICAL,J4LChart::Scale.new())
    xAxis.tickAtBase=true # draw also first tick
    xAxis.scale.min=0
    yAxis.scale.min=0
    yAxis.scale.max=7
    yAxis.scaleTickInterval=1
    xAxis.scaleTickInterval=1
    lbls=[" ","June","July","Aug.","Sept.","Oct.","Nov.","Dec."]
    xAxis.tickLabels=lbls


    xLabel= J4LChart::HAxisLabel.new("",J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,14))
    yLabel= J4LChart::VAxisLabel.new("Brutto",J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,14))

    # plotter
    plot= J4LChart::LinePlotter.new()

		# second plotter
    plot2=J4LChart::BarPlotter.new()

    # create report
    chart=J4LChart::Chart.new()
    chart.resetChart(title,plot2,xAxis,yAxis)
    chart.addPlotter(plot)
    chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN))
    chart.back.colorUntil=J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)
    chart.back.colorFrom=J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE)
    chart.back.gradientType=J4LChart::GRADIENT_VERTICAL
    chart.xLabel=xLabel
    chart.yLabel=yLabel
    chart.legend=l
    chart.layout=J4LChart::LAYOUT_LEGEND_BOTTOM
    plot.addSerie(data2)
    plot2.addSerie(data1)
    plot2.barWidth=20

    return chart

  end


  #
  # Max/Min example
  # @return
  #
  def example14()

    # data
    d1=[2,1 ,2 ,3 ,4 ,5 ,4 ,3]
    dmin1=[1.5,0.85 ,1.5 ,2.8 ,3, 4.8 ,3.5,2.5 ]
    dmax1=[2.3,1.15 ,2.5 ,3.2 ,4.4 ,5.3,4.5 ,3.3]
    data1= J4LChart::MaxMinDataSerie.new(nil,d1)
    data1.drawPoint=true
    data1.drawLineEnd=true
    data1.pointColor=J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)
    data1.setMaxMinValues(dmax1,dmin1)
    data1.maxminStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_NORMAL)

    d2=[2,1 ,2 ,3 ,4 ,5 ,4 ,3]
		  
    data2= J4LChart::LineDataSerie.new(J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_DOTS),d2)
    data2.valueFont=J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,10)
    data2.valueColor=J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN)

    # create title

    title=J4LChart::Title.new("Price")
    title.color=J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE)

    # create axis
    xAxis=J4LChart::Axis.new(J4LChart::HORIZONTAL,J4LChart::Scale.new())
    yAxis=J4LChart::Axis.new(J4LChart::VERTICAL,J4LChart::Scale.new())
    xAxis.tickAtBase=true # draw also first tick
    xAxis.scale.min=0
    yAxis.scale.min=0
    yAxis.scale.max=6
    yAxis.descColor=J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE)
    yAxis.scaleTickInterval=1
    xAxis.scaleTickInterval=1
    xAxis.bigTickInterval=1
    xAxis.descColor=J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE)
    lbls=["8 Jan.","9 Jan.","10 Jan.","11 Jan.","12 Jan.","13 Jan.","14 Jan.","15 Jan."]
    xAxis.tickLabels=lbls
    xAxis.style =J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_NORMAL)
    yAxis.style =J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_NORMAL)

    xLabel= J4LChart::HAxisLabel.new("Week",J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,12))
    yLabel= J4LChart::VAxisLabel.new("Value",J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,12))

    # plotter
    plot=J4LChart::LinePlotter.new()

    # create report
    chart=J4LChart::Chart.new()
    chart.resetChart(title,plot,xAxis,yAxis)
    chart.xLabel=xLabel
    chart.yLabel=yLabel
    chart.addSerie(data2)
    chart.addSerie(data1)
    chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK))

    chart.backImage=J4LChart::GraphicsProvider.getimagefromfile(@imagesDir+"back5.jpg")

    return chart

  end



	#
  # Curves and least squares line example
  # @return
	#
	def example15()

	 	im1=J4LChart::GraphicsProvider.getimagefromfile(@imagesDir+"point.gif")

		im2=J4LChart::GraphicsProvider.getimagefromfile(@imagesDir+"point2.gif")
		# load background
    im3=J4LChart::GraphicsProvider.getimagefromfile(@imagesDir+"back19.jpg")

		# data
    d1=[1,4,3,4,5,4,2]
    d2=[2,3,4,6,6.4,4.5,6.1]

		# series
		data1= J4LChart::LineDataSerie.new(J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),J4LChart::LINE_NORMAL),d1)
		data1.drawPoint=true
		data1.icon=im1
		data1.lineType=J4LChart::TYPE_CUBIC_NATURAL


		data2= J4LChart::LineDataSerie.new(J4LChart::LineStyle.new(2,J4LChart::GraphicsProvider.getcolor(J4LChart::GREEN),J4LChart::LINE_DASHED),d2)
		data2.drawPoint=true
		data2.icon=im2
		data2.lineType=J4LChart::TYPE_LEAST_SQUARES_LINE

		# legend
		l=J4LChart::Legend.new()
		l.addItem("Products",im1)
		l.addItem("Services",im2)

		# create title
		title=J4LChart::Title.new("Sales (thousands $)")
		# create axis
		xAxis=J4LChart::Axis.new(J4LChart::HORIZONTAL,J4LChart::Scale.new())
		yAxis=J4LChart::Axis.new(J4LChart::VERTICAL,J4LChart::Scale.new())
		xAxis.tickAtBase=true # draw also first tick
		xAxis.scale.min=0
		yAxis.scale.min=0
		yAxis.scaleTickInterval=1
		xAxis.scaleTickInterval=1
		yAxis.bigTickInterval=2
		yAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
		lbls=["June","July","Aug.","Sept.","Oct.","Nov.","Dec."]
		xAxis.tickLabels=lbls


		xLabel= J4LChart::HAxisLabel.new("",J4LChart::GraphicsProvider.getcolor(J4LChart::BLUE),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,14))
		yLabel= J4LChart::VAxisLabel.new("Brutto",J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,14))

		# plotter
		plot=J4LChart::CurvePlotter.new()

		# create report
		chart=J4LChart::Chart.new()
    chart.resetChart(title,plot,xAxis,yAxis)
		chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW))
		chart.back.colorFrom=J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW)
		chart.back.colorUntil=J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE)
		chart.back.gradientType=J4LChart::GRADIENT_HORIZONTAL
		chart.xLabel=xLabel
		chart.yLabel=yLabel
		chart.legend=l
		chart.addSerie(data2)
		chart.addSerie(data1)
		chart.backImage=im3

		return chart

  end

	#
  # OCHL chart example
  # @return
  #
  def example11()

		# data
    d1=      [2   ,1    ,2  ,3  ,4.3 ,5   ,4   ,3]
    dclose1=[ 2.3 , 1.15 ,2.5,2.8,4 ,5.1 ,3.5 ,3.2]
    dmin1=[1.5    , 0.85,1.5,2.8,3 , 4.8,3.0 ,2.5 ]
    dmax1=[2.5    ,1.5 ,2.6,3.2, 4.4,5.3,4.5 ,3.3]
		data1= J4LChart::MaxMinDataSerie.new(nil,d1)

    data1.initMaxMin( d1, dclose1,dmax1,dmin1, nil)

		data1.drawLineEnd=false
		data1.setMaxMinValues(dmax1,dmin1)
		data1.maxminStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
		data1.drawPoint=false
		data1.positiveValueColor=J4LChart::GraphicsProvider.getcolor(J4LChart::YELLOW)

		# create title
		title=J4LChart::Title.new("Price")
		title.color=J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK)

		# create axis
    xAxis=J4LChart::Axis.new(J4LChart::HORIZONTAL,J4LChart::Scale.new())
    yAxis=J4LChart::Axis.new(J4LChart::VERTICAL,J4LChart::Scale.new())
		xAxis.tickAtBase=false # draw also first tick
		yAxis.ceroAxis=J4LChart::CEROAXIS_NO
		yAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_DASHED)
		xAxis.scale.min=-1
		yAxis.scale.min=0
		yAxis.scale.max=6
		yAxis.descColor=J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK)
		yAxis.scaleTickInterval=1
		xAxis.scaleTickInterval=1
		xAxis.bigTickInterval=1
		xAxis.gridStyle=J4LChart::LineStyle.new(1,J4LChart::GraphicsProvider.getcolor(J4LChart::WHITE),J4LChart::LINE_DASHED)
		xAxis.descColor=J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK)
		lbls=["8 Jan.","9 Jan.","10 Jan.","11 Jan.","12 Jan.","13 Jan.","14 Jan.","15 Jan."]
		xAxis.tickLabels=lbls
		xAxis.style =J4LChart::LineStyle.new(2,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)
		yAxis.style =J4LChart::LineStyle.new(2,J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::LINE_NORMAL)

		xLabel= J4LChart::HAxisLabel.new("Week",J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,12))
		yLabel= J4LChart::VAxisLabel.new("Value",J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK),J4LChart::GraphicsProvider.getfont("Arial",J4LChart::PLAIN,12))

		# plotter
		plot= J4LChart::LinePlotter.new()
		plot.maxMinType=J4LChart::MM_CANDLESTICK

		# create report
		chart=J4LChart::Chart.new()
    chart.resetChart(title,plot,xAxis,yAxis)
		chart.xLabel=xLabel
		chart.yLabel=yLabel
		chart.addSerie(data1)
		chart.back=J4LChart::FillStyle.new(J4LChart::GraphicsProvider.getcolor(J4LChart::BLACK))

		chart.backImage=J4LChart::GraphicsProvider.getimagefromfile(@imagesDir+"back13.gif")

		return chart

  end



end
