# This file contains examples that show how to create
# a chart using the J4L-chart loader

require 'rubygems'

require 'chart_loader.rb'
require 'chart_image.rb'
require 'chart_graphics.rb'
require 'graphics_provider.rb'

class ChartLoaderExamples

  attr_accessor  :outputDir , :imagesDir

  def initialize
    @outputDir="";
    @imagesDir="";
  end

  def paintBarChartHorizontal()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()

    # axis on top

    cha.setParameter("TITLECHART","Sales")
    cha.setParameter("LEGEND","TRUE")
    cha.setParameter("YLABEL","Month")
    cha.setParameter("XLABEL","Million $")
    cha.setParameter("YAXIS_LABELS","June|July|Aug.|Sept.|Oct.|Nov.|Dec.")
    cha.setParameter("SERIE_1","Products")
    cha.setParameter("SERIE_2","Services")
    cha.setParameter("SERIE_TYPE_1","BAR")
    cha.setParameter("SERIE_TYPE_2","BAR")
    cha.setParameter("SERIE_BAR_STYLE_1","GREEN")
    cha.setParameter("SERIE_BAR_STYLE_2","BLUE")
    cha.setParameter("SERIE_NEGATIVE_STYLE_2","RED")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|8")
    cha.setParameter("SERIE_FONT_2","Arial|PLAIN|8")
    cha.setParameter("SERIE_DATA_1","12|43|50|45|30|32|42")
    cha.setParameter("SERIE_TIPS_1","this is the\n first bar|this is the\nsecond bar|this is the\nthird bar|this is the\n forth bar|this is the\nfifth bar|this is the\nsixth first bar|this is the\nseventh bar")
    cha.setParameter("SERIE_TIPS_2","My tip|My tip|My tip|My tip|My tip|My tip|My tip")
    cha.setParameter("CHART_SHOW_TIPS","true")
    cha.setParameter("CHART_TIPS_COLOR","#FFDC00")
    cha.setParameter("CHART_TIPS_FONT","Serif|ITALIC|10")
    cha.setParameter("SERIE_DATA_2","-10|41|48|39|36|34|50")
    cha.setParameter("CHART_BORDER","0.2|BLACK|LINE")
    cha.setParameter("CHART_FILL","LIGHTGRAY")
    cha.setParameter("BIG_TICK_INTERVALX","10")
    cha.setParameter("BIG_TICK_INTERVALY","1")
    cha.setParameter("XSCALE_MIN","-15")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("YSCALE_MAX","7.8")
    cha.setParameter("LEGEND_BORDER","0.2|BLACK|LINE")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("LEFT_MARGIN","0.15")
    cha.setParameter("BARCHART_VERTICAL","false")
    cha.setParameter("SERIE_BORDER_TYPE_1","RAISED")
    cha.setParameter("SERIE_BORDER_TYPE_2","RAISED")
    cha.setParameter("BARCHART_BARSPACE","1")
    cha.setParameter("XAXIS_ON_TOP","true")
    cha.setParameter("BACK_IMAGE",imagesDir+"back16.gif")
    c=cha.build(false,false)

    c.saveToFile(outputDir+"ChartBarsHorizontal.png")

  end

  def paintChartCurves()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()
    #---------------------------------------------

    # area curves

    cha.setParameter("TITLECHART","Curves")
    cha.setParameter("LEGEND","TRUE")
    cha.setParameter("XLABEL","Month")
    cha.setParameter("YLABEL","Million $")
    cha.setParameter("XAXIS_LABELS","June|July|Aug.|Sept.|Oct.|Nov.|Dec.")
    cha.setParameter("SERIE_1","Cubic Curve")
    cha.setParameter("SERIE_2","Least Squares")
    cha.setParameter("SERIE_3","B-SPLine")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|8")
    cha.setParameter("SERIE_FONT_2","Arial|PLAIN|8")
    cha.setParameter("SERIE_FONT_3","Arial|PLAIN|8")
    cha.setParameter("SERIE_COLOR_1","RED")
    cha.setParameter("SERIE_COLOR_2","BLUE")
    cha.setParameter("SERIE_COLOR_3","GRAY")
    cha.setParameter("SERIE_POINT_COLOR_1","RED")
    cha.setParameter("SERIE_POINT_COLOR_2","BLUE")
    cha.setParameter("SERIE_POINT_COLOR_3","GRAY")
    cha.setParameter("SERIE_POINT_1","true")
    cha.setParameter("SERIE_POINT_2","true")
    cha.setParameter("SERIE_POINT_3","true")
    cha.setParameter("SERIE_STYLE_1","0.2|RED|LINE")
    cha.setParameter("SERIE_STYLE_2","2|GREEN|DASHED")
    cha.setParameter("SERIE_STYLE_3","0.2|GRAY|LINE")
    cha.setParameter("SERIE_FILL_3","YELLOW|0.5")
    cha.setParameter("SERIE_DATA_1","12|43|50|45|30|32|42")
    cha.setParameter("SERIE_DATA_2","20|41|48|39|36|34|50")
    cha.setParameter("SERIE_DATA_3","0|21|28|19|16|14|20")
    cha.setParameter("SERIE_TYPE_1","CURVE")
    cha.setParameter("SERIE_TYPE_2","LINE_LEAST_SQUARES")
    cha.setParameter("SERIE_TYPE_3","B-SPLINES")
    cha.setParameter("CHART_BORDER","0.2|BLACK|LINE")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","10")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("LEGEND_BORDER","0.2|BLACK|LINE")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("XAXIS_GRID","0.2|WHITE|DASHED")
    cha.setParameter("YAXIS_GRID","0.2|WHITE|DASHED")
    cha.setParameter("XAXIS_TICKATBASE","true")
    cha.setParameter("CHART_FILL","AZURE")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"ChartCurves.png")
  end

  def paintChartLogArea()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()

    # areachart log

    cha.setParameter("TITLECHART","Year Sales")
    cha.setParameter("LEGEND","TRUE")
    cha.setParameter("XLABEL","Month")
    cha.setParameter("YLABEL","Million $")
    cha.setParameter("XAXIS_LABELS","June|July|Aug.|Sept.|Oct.|Nov.|Dec.")
    cha.setParameter("SERIE_1","Products")
    cha.setParameter("SERIE_2","Services")
    cha.setParameter("SERIE_STYLE_1","1|#663300|LINE")
    cha.setParameter("SERIE_STYLE_2","1|#000099|LINE")
    cha.setParameter("SERIE_FILL_1","RED")
    cha.setParameter("SERIE_FILL_2","#0099cc")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|8")
    cha.setParameter("SERIE_FONT_2","Arial|PLAIN|8")
    cha.setParameter("SERIE_POINT_1","true")
    cha.setParameter("SERIE_POINT_2","true")
    cha.setParameter("SERIE_DATA_2","12|80|300|450|300|320|420")
    cha.setParameter("SERIE_DATA_1","32|140|700|600|760|760|930")
    cha.setParameter("SERIE_TYPE_1","LINE")
    cha.setParameter("SERIE_TYPE_2","LINE")
    cha.setParameter("CHART_BORDER","0.2|BLACK|LINE")
    cha.setParameter("CHART_FILL","YELLOW")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","1")
    cha.setParameter("TICK_INTERVALY","10")
    cha.setParameter("LEGEND_BORDER","1|BLACK|LINE")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("XAXIS_TICKATBASE","true")
    cha.setParameter("XAXIS_TICKATBASE","true")
    cha.setParameter("TICK_LOG_INTERVALY","true")
    cha.setParameter("YSCALE_LOG","true")
    cha.setParameter("YSCALE_LOG_BASE","10")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("YSCALE_MAX","1000")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"ChartLogArea.png")
  end

  def paintChartLineClipping()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()

    # clipping

    cha.setParameter("TITLECHART","Sales 1999")
    cha.setParameter("LEGEND","TRUE")
    cha.setParameter("XLABEL","Month")
    cha.setParameter("YLABEL","Million $")
    cha.setParameter("XAXIS_LABELS","June|July|Aug.|Sept.|Oct.|Nov.|Dec.")
    cha.setParameter("SERIE_1","Products")
    cha.setParameter("SERIE_2","Services")
    cha.setParameter("SERIE_STYLE_1","2|#ff0000|LINE")
    cha.setParameter("SERIE_STYLE_2","2|#000055|LINE")
    cha.setParameter("SERIE_FILL_2","#000099")
    cha.setParameter("SERIE_FONT_1","DEFAULT-3")
    cha.setParameter("SERIE_FONT_2","DEFAULT-3")
    cha.setParameter("SERIE_POINT_1","TRUE")
    cha.setParameter("SERIE_POINT_2","TRUE")
    cha.setParameter("SERIE_DATA_2","12|80|200|450|300|320|420")
    cha.setParameter("SERIE_DATA_1","32|140|700|1300|760|760|930")
    cha.setParameter("SERIE_TYPE_1","LINE")
    cha.setParameter("SERIE_TYPE_2","LINE")
    cha.setParameter("CHART_BORDER","0.2|BLACK|LINE")
    cha.setParameter("CHART_FILL","YELLOW")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","1")
    cha.setParameter("TICK_INTERVALY","100")
    cha.setParameter("LEGEND_BORDER","1|BLACK|LINE")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("XAXIS_TICKATBASE","true")
    cha.setParameter("YSCALE_LOG","FALSE")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("YSCALE_MAX","1000")
    cha.setParameter("SAVE","1")
    cha.setParameter("SERIE_SECONDYAXIS_1","FALSE")
    cha.setParameter("SERIE_BORDER_TYPE_1","NORMAL")
    cha.setParameter("SERIE_DRAW_LINE_1","TRUE")
    cha.setParameter("SERIE_LINE_TYPE_1","NORMAL")
    cha.setParameter("SERIE_NEEDLE_STYLE_1","3|#000000|NORMAL")
    cha.setParameter("SERIE_NEEDLE_LENTGH_1","80")
    cha.setParameter("SERIE_BUBBLE_1","FALSE")
    cha.setParameter("SERIE_FILL_BUBBLE_1","FALSE")
    cha.setParameter("SERIE_LINE_END_1","FALSE")
    cha.setParameter("NODE","SERIE2")
    cha.setParameter("YLABEL_VERTICAL","FALSE")
    cha.setParameter("YAXIS","TRUE")
    cha.setParameter("YAXIS_TICKATBASE","FALSE")
    cha.setParameter("GRIDY","FALSE")
    cha.setParameter("YAXIS_START_WITH_BIG_TICK","FALSE")
    cha.setParameter("CERO_YAXIS","NO")
    cha.setParameter("YAXIS_INTEGER","TRUE")
    cha.setParameter("YAXIS_VERTICAL_LABELS","FALSE")
    cha.setParameter("YAXIS_TICK_TEXT_LINE","0")
    cha.setParameter("YAXIS_CLOSED","FALSE")
    cha.setParameter("YSCALE_EXACT_MAX","FALSE")
    cha.setParameter("YSCALE_EXACT_MIN","TRUE")
    cha.setParameter("SERIE_SECONDYAXIS_2","FALSE")
    cha.setParameter("SERIE_BORDER_TYPE_2","NORMAL")
    cha.setParameter("SERIE_DRAW_LINE_2","TRUE")
    cha.setParameter("SERIE_LINE_TYPE_2","NORMAL")
    cha.setParameter("SERIE_NEEDLE_STYLE_2","3|#000000|NORMAL")
    cha.setParameter("SERIE_NEEDLE_LENTGH_2","80")
    cha.setParameter("SERIE_BUBBLE_2","FALSE")
    cha.setParameter("SERIE_FILL_BUBBLE_2","FALSE")
    cha.setParameter("SERIE_LINE_END_2","FALSE")
    cha.setParameter("LINECHART_FIXED_LIMITS","TRUE")
    cha.setParameter("LINECHART_POINT_SIZE","6")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"ChartLineClipping.png")

  end

  def paintChartNullValue()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()
    #------------------------------

    # line nulls

    cha.setParameter("TITLECHART","Sales")
    cha.setParameter("LEGEND","TRUE")
    cha.setParameter("YLABEL_VERTICAL","true")
    cha.setParameter("XLABEL","Month")
    cha.setParameter("YLABEL","Million $")
    cha.setParameter("XAXIS_LABELS","June|July|Aug.|Sept.|Oct.|Nov.|Dec.")
    cha.setParameter("SERIE_1","Products")
    cha.setParameter("SERIE_2","Services")
    cha.setParameter("SERIE_STYLE_1","2|#ff0000|LINE")
    cha.setParameter("SERIE_STYLE_2","2|#000055|LINE")
    cha.setParameter("SERIE_FILL_2","#000099")
    cha.setParameter("SERIE_FONT_1","DEFAULT-3")
    cha.setParameter("SERIE_FONT_2","DEFAULT-3")
    cha.setParameter("SERIE_POINT_1","TRUE")
    cha.setParameter("SERIE_POINT_2","TRUE")
    cha.setParameter("SERIE_DATA_2","12|80|200|450|300|320|420")
    cha.setParameter("SERIE_DATA_1","32|140|700|NULL|760|760|930")
    cha.setParameter("SERIE_TYPE_1","LINE")
    cha.setParameter("SERIE_TYPE_2","LINE")
    cha.setParameter("CHART_BORDER","0.2|BLACK|LINE")
    cha.setParameter("CHART_FILL","YELLOW")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","1")
    cha.setParameter("TICK_INTERVALY","100")
    cha.setParameter("LEGEND_BORDER","1|BLACK|LINE")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("XAXIS_TICKATBASE","true")
    cha.setParameter("YSCALE_LOG","FALSE")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("YSCALE_MAX","1000")
    cha.setParameter("SAVE","1")
    cha.setParameter("SERIE_SECONDYAXIS_1","FALSE")
    cha.setParameter("SERIE_BORDER_TYPE_1","NORMAL")
    cha.setParameter("SERIE_DRAW_LINE_1","TRUE")
    cha.setParameter("SERIE_LINE_TYPE_1","NORMAL")
    cha.setParameter("SERIE_NEEDLE_STYLE_1","3|#000000|NORMAL")
    cha.setParameter("SERIE_NEEDLE_LENTGH_1","80")
    cha.setParameter("SERIE_BUBBLE_1","FALSE")
    cha.setParameter("SERIE_FILL_BUBBLE_1","FALSE")
    cha.setParameter("SERIE_LINE_END_1","FALSE")
    cha.setParameter("NODE","SERIE1")
    cha.setParameter("YLABEL_VERTICAL","FALSE")
    cha.setParameter("YAXIS","TRUE")
    cha.setParameter("YAXIS_TICKATBASE","FALSE")
    cha.setParameter("GRIDY","FALSE")
    cha.setParameter("YAXIS_START_WITH_BIG_TICK","FALSE")
    cha.setParameter("CERO_YAXIS","NO")
    cha.setParameter("YAXIS_INTEGER","TRUE")
    cha.setParameter("YAXIS_VERTICAL_LABELS","FALSE")
    cha.setParameter("YAXIS_TICK_TEXT_LINE","0")
    cha.setParameter("YAXIS_CLOSED","FALSE")
    cha.setParameter("YSCALE_EXACT_MAX","FALSE")
    cha.setParameter("YSCALE_EXACT_MIN","TRUE")
    cha.setParameter("SERIE_SECONDYAXIS_2","FALSE")
    cha.setParameter("SERIE_BORDER_TYPE_2","NORMAL")
    cha.setParameter("SERIE_DRAW_LINE_2","TRUE")
    cha.setParameter("SERIE_LINE_TYPE_2","NORMAL")
    cha.setParameter("SERIE_NEEDLE_STYLE_2","3|#000000|NORMAL")
    cha.setParameter("SERIE_NEEDLE_LENTGH_2","80")
    cha.setParameter("SERIE_BUBBLE_2","FALSE")
    cha.setParameter("SERIE_FILL_BUBBLE_2","FALSE")
    cha.setParameter("SERIE_LINE_END_2","FALSE")
    cha.setParameter("LINECHART_FIXED_LIMITS","FALSE")
    cha.setParameter("LINECHART_POINT_SIZE","6")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"ChartNullValue.png")
  end

  def paintScatterChart()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()

    #  scatter
    cha.setParameter("TITLECHART","Sales")
    cha.setParameter("XLABEL","Month")
    cha.setParameter("YLABEL","Million $")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","10")
    cha.setParameter("XAXIS_LABELS","June|July|Aug.|Sept.|Oct.|Nov.|Dec.")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("LEGEND_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("SERIE_1","Products")
    cha.setParameter("SERIE_2","Services")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|9")
    cha.setParameter("SERIE_FONT_2","Arial|PLAIN|9")
    cha.setParameter("SERIE_DATA_1","32|84|90|60|76|76|42")
    cha.setParameter("XAXIS_TICKATBASE","true")
    cha.setParameter("SERIE_DATA_2","12|43|50|45|30|32|93")
    cha.setParameter("SERIE_DRAW_LINE_1","FALSE")
    cha.setParameter("SERIE_DRAW_LINE_2","FALSE")
    cha.setParameter("SERIE_POINT_1","true")
    cha.setParameter("SERIE_POINT_2","true")
    cha.setParameter("CHART_BORDER","1|#000000|NORMAL")
    cha.setParameter("CHART_FILL","WHITE")
    cha.setParameter("SERIE_POINT_IMAGE_1",imagesDir+"point.gif")
    cha.setParameter("SERIE_POINT_IMAGE_2",imagesDir+"point2.gif")
    cha.setParameter("XAXIS_CLOSED","TRUE")
    cha.setParameter("YAXIS_CLOSED","TRUE")
    cha.setParameter("LEGEND_MARGIN","0.25")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"ScatterChart.png")
  end

  def paintBubbleChart()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()
    cha.setParameter("TITLECHART","Sales 1999")
    cha.setParameter("LEGEND","TRUE")
    cha.setParameter("XLABEL","Month")
    cha.setParameter("YLABEL","Million $")
    cha.setParameter("XAXIS_LABELS","May|June|July|Aug.|Sept.|Oct.|Nov.|Dec.")
    cha.setParameter("SERIE_1","Products")
    cha.setParameter("SERIE_2","Services")
    cha.setParameter("SERIE_STYLE_1","NULL")
    cha.setParameter("SERIE_FONT_1","NULL")
    cha.setParameter("SERIE_FONT_2","Arial|PLAIN|8")
    cha.setParameter("SERIE_COLOR_1","RED")
    cha.setParameter("SERIE_COLOR_2","BLUE")
    cha.setParameter("SERIE_POINT_COLOR_1","RED")
    cha.setParameter("SERIE_POINT_COLOR_2","BLUE")
    cha.setParameter("SERIE_POINT_1","FALSE")
    cha.setParameter("SERIE_POINT_2","true")
    cha.setParameter("SERIE_STYLE_2","0.2|BLUE|LINE")
    cha.setParameter("SERIE_DATA_1","12|43|50|45|30|32|42|50")
    cha.setParameter("SERIE_MAX_DATA_1","1|2|3|1|0|6|3|0")
    cha.setParameter("SERIE_DATA_2","12|43|50|45|30|32|42|50")
    cha.setParameter("SERIE_BUBBLE_1","TRUE")
    cha.setParameter("SERIE_FILL_BUBBLE_1","TRUE")
    cha.setParameter("SERIE_TYPE_1","LINE")
    cha.setParameter("SERIE_TYPE_2","LINE")
    cha.setParameter("CHART_BORDER","1|BLACK|LINE")
    cha.setParameter("CHART_FILL","#FFFF80")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","10")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("LEGEND_BORDER","1|BLACK|LINE")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("XAXIS_GRID","0.2|#808080|DASHED")
    cha.setParameter("YAXIS_GRID","0.2|#808080|DASHED")
    cha.setParameter("XAXIS_TICKATBASE","true")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"BubbleChart.png")
  end

  def paintChartTargetZones()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()
    cha.setParameter("WIDTH","400")
    cha.setParameter("HEIGHT","400")
    cha.setParameter("TITLECHART","Hotel ABC")
    cha.setParameter("TITLE_FONT","ARIAL|BOLD|18")
    cha.setParameter("XLABEL","Date")
    cha.setParameter("YLABEL","Room Reservations")
    cha.setParameter("YLABEL_VERTICAL","true")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("YSCALE_MAX","100")
    cha.setParameter("TICK_INTERVALY","10")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","1")
    cha.setParameter("XAXIS_TICKATBASE","TRUE")
    cha.setParameter("XAXIS_GRID","1|#A0A0A0|NORMAL")
    cha.setParameter("YAXIS_GRID","1|#A0A0A0|NORMAL")
    cha.setParameter("YAXIS_FILL_GRID","#E0E0E0")
    cha.setParameter("GRIDY","true")
    cha.setParameter("YAXIS_START_WITH_BIG_TICK","true")
    cha.setParameter("XAXIS_DATE_FORMAT","%a")
    cha.setParameter("XAXIS_INITIAL_DATE","02/02/2005")
    cha.setParameter("LEGEND","FALSE")
    cha.setParameter("SERIE_1","Reservations")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|8")
    cha.setParameter("SERIE_DATA_1","60|73|59|45|90|92|52")
    cha.setParameter("SERIE_STYLE_1","2|GREEN|LINE")
    cha.setParameter("LINECHART_BACK","WHITE")
    cha.setParameter("LEFT_MARGIN","0.15")
    cha.setParameter("CHART_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("CHART_FILL","LIGHTYELLOW")
    cha.setParameter("CHART_TARGET_ZONE_1","3;5;1|BLACK|NORMAL;LIGHTBLUE|0.5;@font value='ARIAL|PLAIN|12'@@Position value=',-25px'@Weekend;TRUE")
    cha.setParameter("CHART_TARGET_ZONE_2","30;;2|RED|NORMAL;;@Position value='15%,-25px'@@font value='ARIAL|ITALIC|12'@Profitability threshold;FALSE")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"ChartTargetZones.png")

  end

  def paintCandleStick()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()

    cha.setParameter("TITLECHART","Price")
    cha.setParameter("LEGEND","FALSE")
    cha.setParameter("XLABEL","Day")
    cha.setParameter("YLABEL","Million $")
    cha.setParameter("XAXIS_INITIAL_DATE","10/10/2001")
    cha.setParameter("XAXIS_DATE_STEP","d")
    cha.setParameter("XAXIS_DATE_FORMAT","%d-%b")
    cha.setParameter("SERIE_1","Products")
    cha.setParameter("SERIE_COLOR_1","RED")
    cha.setParameter("SERIE_DATA_1","22|43|50|45|55|32|42")
    cha.setParameter("SERIE_DATAX_1","1|2|3|5|5|6|7")
    cha.setParameter("SERIE_CLOSE_DATA_1","24|45|41|54|30|35|45")
    cha.setParameter("SERIE_MAX_DATA_1","28|47|52|55|60|37|49")
    cha.setParameter("SERIE_MIN_DATA_1","20|39|39|40|30|30|36")
    cha.setParameter("SSERIE_MAXMIN_STYLE_1","0.2|BLACK|LINE")
    cha.setParameter("SERIE_DRAW_LINE_1","N")
    cha.setParameter("SERIE_LINE_TYPE_1","CANDLESTICK")
    cha.setParameter("SERIE_TYPE_1","LINE")
    cha.setParameter("CHART_BORDER","0.2|BLACK|LINE")
    cha.setParameter("CHART_FILL","YELLOW")
    cha.setParameter("BIG_TICK_INTERVALX","2")
    cha.setParameter("BIG_TICK_INTERVALY","10")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("LEGEND_BORDER","0.2|BLACK|LINE")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("XAXIS_GRID","0.2|WHITE|DASHED")
    cha.setParameter("YAXIS_GRID","0.2|WHITE|DASHED")
    cha.setParameter("XSCALE_MIN","-1")
    cha.setParameter("XSCALE_MIN","0")
    cha.setParameter("YSCALE_MAX","70")
    cha.setParameter("XAXIS_TICKATBASE","true")
    cha.setParameter("CERO_YAXIS","NO")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"CandleStick.png")
  end

  def paintStackedBars()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()
    cha.setParameter("TITLECHART","Sales")
    cha.setParameter("XLABEL","Month")
    cha.setParameter("YLABEL","Million $")
    cha.setParameter("XSCALE_MAX","5.5")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("BARCHART_CUMULATIVE","true")
    cha.setParameter("SERIE_TIPS_1","12|43|50|45|30")
    cha.setParameter("BIG_TICK_INTERVALY","10")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("XAXIS_LABELS","June|July|Aug.|Sept.|Oct.|Nov.|Dec.")
    cha.setParameter("CERO_XAXIS","LINE")
    cha.setParameter("YAXIS_INTEGER","TRUE")
    cha.setParameter("SERIE_1","Products")
    cha.setParameter("SERIE_2","Services")
    cha.setParameter("SERIE_TYPE_1","BAR")
    cha.setParameter("SERIE_TYPE_2","BAR")
    cha.setParameter("SERIE_FONT_1","Arial|8")
    cha.setParameter("SERIE_FONT_2","Arial|8")
    cha.setParameter("SERIE_DATA_1","12|43|50|45|30")
    cha.setParameter("SERIE_DATA_2","10|41|48|39|36")
    cha.setParameter("SERIE_BORDER_TYPE_1","RAISED")
    cha.setParameter("SERIE_BORDER_TYPE_2","RAISED")
    cha.setParameter("SERIE_BAR_STYLE_1","#00FF00")
    cha.setParameter("SERIE_BAR_STYLE_2","#0000FF")
    cha.setParameter("LEFT_MARGIN","0.15")
    cha.setParameter("CHART_FILL","#FFCC00")
    cha.setParameter("SERIE_NEGATIVE_STYLE_2","RED")
    cha.setParameter("YLABEL_VERTICAL","TRUE")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"StackedBars.png")
  end

  def paintMultiCharts()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()
    cha.setParameter("WIDTH","500")
    cha.setParameter("HEIGHT","400")
    cha.setParameter("TITLECHART","@align value='CENTER'@Sales comparison\\n@Font value='Arial|PLAIN|9'@Comparison of last year and last 4 years")
    cha.setParameter("TITLE_FONT","ARIAL|BOLD|18")
    cha.setParameter("YLABEL","Products")
    cha.setParameter("YLABEL_VERTICAL","TRUE")
    cha.setParameter("X_1AXIS","TRUE")
    cha.setParameter("Y_1AXIS","TRUE")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("X_1SCALE_MIN","0")
    cha.setParameter("Y_1SCALE_MIN","0")
    cha.setParameter("XSCALE_MAX","4.5")
    cha.setParameter("YSCALE_MAX","100")
    cha.setParameter("X_1SCALE_MAX","4")
    cha.setParameter("Y_1SCALE_MAX","20")
    cha.setParameter("TICK_INTERVALY","10")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","1")
    cha.setParameter("BIG_TICK_INTERVALX_1","1")
    cha.setParameter("YAXIS_GRID","1.0|#a0a0a0|NORMAL")
    cha.setParameter("Y_1AXIS_GRID","1.0|#a0a0a0|NORMAL")
    cha.setParameter("GRIDY","TRUE")
    cha.setParameter("GRIDY_1","TRUE")
    cha.setParameter("XAXIS_LABELS","Mar.|Jun.|Sept.|Dec.")
    cha.setParameter("X_1AXIS_LABELS","2002|2003|2004|2005")
    cha.setParameter("YAXIS_START_WITH_BIG_TICK","TRUE")
    cha.setParameter("XAXIS_BAR_STYLE","BAR")
    cha.setParameter("YAXIS_BAR_STYLE","BAR")
    cha.setParameter("X_1AXIS_BAR_STYLE","BAR")
    cha.setParameter("Y_1AXIS_BAR_STYLE","BAR")
    cha.setParameter("XAXIS_FILLING","#ffc800")
    cha.setParameter("YAXIS_FILLING","LIGHTSALMON")
    cha.setParameter("X_1AXIS_FILLING","WHITE")
    cha.setParameter("Y_1AXIS_FILLING","LIGHTBLUE")
    cha.setParameter("YAXIS_LABEL","Hight End")
    cha.setParameter("Y_1AXIS_LABEL","Low End")
    cha.setParameter("XAXIS_STACK_ADDITIONAL","TRUE")
    cha.setParameter("YAXIS_STACK_ADDITIONAL","TRUE")
    cha.setParameter("X_1SCALE_EXACT_MAX","FALSE")
    cha.setParameter("XAXIS_DATE_FORMAT","%a")
    cha.setParameter("XAXIS_INITIAL_DATE","02/02/2005")
    cha.setParameter("LEGEND","FALSE")
    cha.setParameter("SERIE_1","Low4")
    cha.setParameter("SERIE_2","High")
    cha.setParameter("SERIE_3","High4")
    cha.setParameter("SERIE_4","Low")
    cha.setParameter("SERIE_TYPE_1","CURVE")
    cha.setParameter("SERIE_TYPE_2","BAR")
    cha.setParameter("SERIE_TYPE_3","CURVE")
    cha.setParameter("SERIE_TYPE_4","BAR")
    cha.setParameter("SERIE_SECONDARY_XAXIS_1","1")
    cha.setParameter("SERIE_SECONDARY_XAXIS_3","1")
    cha.setParameter("SERIE_SECONDARY_YAXIS_1","1")
    cha.setParameter("SERIE_SECONDARY_YAXIS_4","1")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|8")
    cha.setParameter("SERIE_FONT_2","Arial|PLAIN|8")
    cha.setParameter("SERIE_FONT_3","Arial|PLAIN|8")
    cha.setParameter("SERIE_FONT_4","Arial|PLAIN|8")
    cha.setParameter("SERIE_DATA_1","10|7|9|5")
    cha.setParameter("SERIE_DATA_2","60|73|59|45")
    cha.setParameter("SERIE_DATA_3","40|70|90|40")
    cha.setParameter("SERIE_DATA_4","5|2|3|4")
    cha.setParameter("SERIE_BAR_STYLE_2","LIGHTSALMON")
    cha.setParameter("SERIE_BAR_STYLE_4","#add8e6")
    cha.setParameter("SERIE_STYLE_1","2.0|#bcd8d6|NORMAL")
    cha.setParameter("SERIE_STYLE_3","2.0|#ef806a|NORMAL")
    cha.setParameter("SERIE_FILL_1","#add8e6")
    cha.setParameter("SERIE_FILL_3","#ffa07a")
    cha.setParameter("SERIE_NEEDLE_STYLE_1","3.0|#000000|NORMAL")
    cha.setParameter("SERIE_NEEDLE_STYLE_2","3.0|#000000|NORMAL")
    cha.setParameter("SERIE_NEEDLE_STYLE_3","3.0|#000000|NORMAL")
    cha.setParameter("SERIE_NEEDLE_STYLE_4","3.0|#000000|NORMAL")
    cha.setParameter("BARCHART_CUMULATIVE","true")
    cha.setParameter("LINECHART_BACK","WHITE")
    cha.setParameter("LINECHART_START_VALUE_X","1")
    cha.setParameter("LEFT_MARGIN","0.20")
    cha.setParameter("TOP_MARGIN","0.2")
    cha.setParameter("BOTTOM_MARGIN","0.2")
    cha.setParameter("CHART_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("CHART_FILL","#ccffbb")
    cha.setParameter("CHART_NOTE1","@position value='30%,90%'@@size value='0px,22px'@@border value='1|BLACK|NORMAL'@@background value='WHITE'@@font value='Arial|BOLD|12'@ Last year")
    cha.setParameter("CHART_NOTE2","@position value='60%,90%'@@size value='0px,22px'@@border value='1|BLACK|NORMAL'@@background value='WHITE'@@font value='Arial|BOLD|12'@ Last 4 years")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"MultiCharts.png")
  end
  
  
  def paintChartNotes()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()
    cha.setParameter("WIDTH","400")
    cha.setParameter("HEIGHT","400")
    cha.setParameter("TITLECHART","Server response time@font value='Serif|PLAIN|10'@\\nMonday 2-May-2005")
    cha.setParameter("TITLE_FONT","Serif|BOLD|14")
    cha.setParameter("YLABEL","Seconds")
    cha.setParameter("YLABEL_VERTICAL","TRUE")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("YSCALE_MAX","5")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","1")
    cha.setParameter("XAXIS_TICKATBASE","TRUE")
    cha.setParameter("XAXIS_LABELS"," 00:00| 6:00| 12:00| 18:00| 24:00")
    cha.setParameter("XAXIS_ROTATE_LABELS","45")
    cha.setParameter("LEGEND","FALSE")
    cha.setParameter("SERIE_1","serie")
    cha.setParameter("SERIE_TYPE_1","CURVE")
    cha.setParameter("SERIE_DATA_1","5|2|3|4|4.5")
    cha.setParameter("SERIE_STYLE_1","1.0|#000000|NORMAL")
    cha.setParameter("SERIE_FILL_1","RED")
    cha.setParameter("SERIE_POINT_1","TRUE")
    cha.setParameter("SERIE_NEEDLE_STYLE_1","3.0|#000000|NORMAL")
    cha.setParameter("BARCHART_BACK","#ffffff")
    cha.setParameter("BOTTOM_MARGIN","0.15")
    cha.setParameter("CHART_FILL","#eeffff")
    cha.setParameter("CHART_NOTE1","@position value='0px,94%'@@size value='100%,6%'@ @background value='#33ccff'@Copyright J4L Examples")
    cha.setParameter("CHART_NOTE2","@image value='"+imagesDir+"warning.PNG'@ @ANCHOR value='1,2' line='1|GRAY|DOTS'@ @position value='15%,15%'@Manual tunning\\n            performed at 6:00")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"ChartNotes.png")
  end

  def paintMultipleAxis()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()
    cha.setParameter("WIDTH","440")
    cha.setParameter("HEIGHT","400")
    cha.setParameter("TITLECHART","@align value='CENTER'@Survey Results\\n@Font value='Arial|PLAIN|9'@Coffee machine Customer Satisfaction survey\\nconducted by two independent consultants")
    cha.setParameter("TITLE_FONT","ARIAL|BOLD|18")
    cha.setParameter("XLABEL","Coffee Machine")
    cha.setParameter("YLABEL","Results")
    cha.setParameter("YLABEL_VERTICAL","true")
    cha.setParameter("Y_1AXIS","TRUE")
    cha.setParameter("Y_2AXIS","TRUE")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("Y_1SCALE_MIN","0")
    cha.setParameter("Y_2SCALE_MIN","0")
    cha.setParameter("YSCALE_MAX","100")
    cha.setParameter("Y_1SCALE_MAX","20")
    cha.setParameter("Y_2SCALE_MAX","1")
    cha.setParameter("TICK_INTERVALY","10")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","1")
    cha.setParameter("YAXIS_GRID","1|#A0A0A0|NORMAL")
    cha.setParameter("GRIDY","true")
    cha.setParameter("XAXIS_LABELS","Acme\\nplus|Pato\\nexpress|Rowe|Acme\\nsupreme")
    cha.setParameter("YAXIS_START_WITH_BIG_TICK","true")
    cha.setParameter("YAXIS_BAR_STYLE","BAR")
    cha.setParameter("Y_1AXIS_BAR_STYLE","BAR")
    cha.setParameter("Y_2AXIS_BAR_STYLE","BAR")
    cha.setParameter("YAXIS_FILLING","LIGHTSALMON")
    cha.setParameter("Y_1AXIS_FILLING","LIGHTBLUE")
    cha.setParameter("Y_2AXIS_FILLING","WHITE")
    cha.setParameter("YAXIS_LABEL","Survey 2")
    cha.setParameter("Y_1AXIS_LABEL","Survey 1")
    cha.setParameter("Y_2AXIS_TARGET_ZONE_1","0%;30%;;RED;@rotation value='90'@@color value='RED'@Dissatisfied")
    cha.setParameter("Y_2AXIS_TARGET_ZONE_2","70%;100%;;GREEN;@rotation value='90'@@color value='GREEN'@Satisfied")
    cha.setParameter("XAXIS_DATE_FORMAT","%a")
    cha.setParameter("XAXIS_INITIAL_DATE","02/02/2005")
    cha.setParameter("LEGEND","FALSE")
    cha.setParameter("SERIE_1","survey1")
    cha.setParameter("SERIE_2","survey2")
    cha.setParameter("SERIE_TYPE_1","BAR")
    cha.setParameter("SERIE_TYPE_2","BAR")
    cha.setParameter("SERIE_SECONDARY_YAXIS_1","1")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|8")
    cha.setParameter("SERIE_FONT_2","Arial|PLAIN|8")
    cha.setParameter("SERIE_DATA_1","10|7|9|5")
    cha.setParameter("SERIE_DATA_2","60|73|59|45")
    cha.setParameter("SERIE_STYLE_1","LIGHTBLUE")
    cha.setParameter("SERIE_STYLE_2","LIGHTSALMON")
    cha.setParameter("LINECHART_BACK","WHITE")
    cha.setParameter("LEFT_MARGIN","0.30")
    cha.setParameter("TOP_MARGIN","0.2")
    cha.setParameter("BOTTOM_MARGIN","0.2")
    cha.setParameter("CHART_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("CHART_FILL","LIGHTYELLOW")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"MultipleAxis.png")
  end
  
  def paintEventChart()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()
    cha.setParameter("TITLECHART","Event Chart")
    cha.setParameter("LEGEND","TRUE")
    cha.setParameter("YLABEL","2")
    cha.setParameter("XLABEL","Time")
    cha.setParameter("XAXIS_INITIAL_DATE","10/10/2001")
    cha.setParameter("XAXIS_DATE_STEP","d")
    cha.setParameter("XAXIS_DATE_FORMAT","d-%b")
    cha.setParameter("SERIE_1","Act. A")
    cha.setParameter("SERIE_TYPE_1","BAR")
    cha.setParameter("SERIE_BAR_STYLE_1","GREEN")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|8")
    cha.setParameter("SERIE_DATAX_1","0|0|0")
    cha.setParameter("SERIE_DATA_1","5|27|44")
    cha.setParameter("SERIE_BARS_START_1","2|15|30")
    cha.setParameter("SERIE_2","Act. B")
    cha.setParameter("SERIE_TYPE_2","BAR")
    cha.setParameter("SERIE_BAR_STYLE_2","BLUE")
    cha.setParameter("SERIE_FONT_2","Arial|PLAIN|8")
    cha.setParameter("SERIE_DATAX_2","1|1|1")
    cha.setParameter("SERIE_DATA_2","7|15|24")
    cha.setParameter("SERIE_DATA_LABELS_2","2 days|5 days |4 days")
    cha.setParameter("SERIE_DATA_LABELS_1","3 days|12 days|2 weeks")
    cha.setParameter("XAXIS_ON_TOP","true")
    cha.setParameter("SERIE_BARS_START_2","5|10|20")
    cha.setParameter("CHART_BORDER","0.2|BLACK|LINE")
    cha.setParameter("CHART_FILL","YELLOW")
    cha.setParameter("BIG_TICK_INTERVALX","5")
    cha.setParameter("TICK_INTERVALX","2")
    cha.setParameter("BIG_TICK_INTERVALY","1")
    cha.setParameter("YSCALE_MAX","3")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("XSCALE_MIN","0")
    cha.setParameter("XSCALE_Max","50")
    cha.setParameter("XSCALE_EXACT_MAX","true")
    cha.setParameter("XAXIS_START_WITH_BIG_TICK","true")
    cha.setParameter("YAXIS_LABELS","Act. A|Act. B")
    cha.setParameter("LEGEND_BORDER","0.2|BLACK|LINE")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("LEFT_MARGIN","0.15")
    cha.setParameter("BARCHART_VERTICAL","false")
    cha.setParameter("SERIE_BORDER_TYPE_1","RAISED")
    cha.setParameter("SERIE_BORDER_TYPE_2","RAISED")
    cha.setParameter("BARCHART_BARWIDTH","20")
    cha.setParameter("BARCHART_EVENTCHART","true")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"EventChart.png")
  end

  def paintPieChart3D()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()
    cha.setParameter("LEGEND","TRUE")
    cha.setParameter("LEGEND_POSITION","BOTTOM")
    cha.setParameter("LEGEND_VERTICAL","false")
    cha.setParameter("LEGEND_MARGIN","0.12")
    cha.setParameter("LEGEND_BORDER","1|BLACK|LINE")
    cha.setParameter("YLABEL","Factor A")
    cha.setParameter("YLABEL_FONT","Verdana|PLAIN|10")
    cha.setParameter("Y2LABEL_VERTICAL","true")
    cha.setParameter("YLABEL_VERTICAL","true")
    cha.setParameter("Y2LABEL","Measure")
    cha.setParameter("Y2LABEL_FONT","Verdana|PLAIN|10")
    cha.setParameter("SERIE_1","Factor A")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|7")
    cha.setParameter("SERIE_FORMAT_1","#.0")
    cha.setParameter("SERIE_DATA_1","1396.5|1402.389|1408.278|1414.167|1420.056|425.944|1531.833|1637.722|1743.611|1449.5")
    cha.setParameter("SERIE_STYLE_1","3|#F5B549|LINE")
    cha.setParameter("SERIE_TYPE_1","LINE")
    cha.setParameter("SERIE_DATAX_1","1|2|3|4|5|6|7|8|9|10")
    cha.setParameter("SERIE_2","Measure")
    cha.setParameter("SERIE_DATA_2","0|0|0|0|300|1000|400|700|0|0")
    cha.setParameter("SERIE_TYPE_2","BAR")
    cha.setParameter("SERIE_BAR_STYLE_2","#EEEEEE")
    cha.setParameter("SERIE_FONT_2","NULL")
    cha.setParameter("SERIE_COLOR_2","BLACK")
    cha.setParameter("BARCHART_BARWIDTH","20")
    cha.setParameter("SERIE_SECONDYAXIS_2","TRUE")
    cha.setParameter("BIG_TICK_INTERVALY","2")
    cha.setParameter("TICK_INTERVALY","244")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("YSCALE_MAX","3844")
    cha.setParameter("XSCALE_MAX","11")
    cha.setParameter("YAXIS_AUTO_TICKS","true")
    cha.setParameter("XAXIS_GRID","1|#DDDDDD|LINE")
    cha.setParameter("XAXIS_INITIAL_DATE","10/10/2003")
    cha.setParameter("XAXIS_DATE_STEP","d")
    cha.setParameter("XAXIS_DATE_FORMAT","%d-%b")
    cha.setParameter("XAXIS_TICKATBASE","false")
    cha.setParameter("BIG_TICK_INTERVALX","2")
    cha.setParameter("TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY2","2")
    cha.setParameter("TICK_INTERVALY2","95")
    cha.setParameter("Y2SCALE_MIN","0")
    cha.setParameter("Y2SCALE_MAX","953")
    cha.setParameter("Y2AXIS","true")
    cha.setParameter("YAXIS_GRID","1|#DDDDDD|LINE")
    cha.setParameter("CHART_SECOND_AXIS_MARGIN","0")
    cha.setParameter("CHART_FILL","#FFFFFF")
    cha.setParameter("CHART_SHOW_POSITION","true")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"PieChart3D.png")

  end

  def paintBarChart3D()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()
    cha.setParameter("TITLECHART","Some bars will be updated every 2 seconds")
    cha.setParameter("YLABEL_VERTICAL","true")
    cha.setParameter("XLABEL","Month")
    cha.setParameter("YLABEL","Million $")
    cha.setParameter("XSCALE_MIN","0")
    cha.setParameter("YSCALE_MIN","-15")
    cha.setParameter("XSCALE_MAX","7")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","10")
    cha.setParameter("XAXIS_GRID","0.2|LIGHTGRAY|DASHED")
    cha.setParameter("YAXIS_GRID","0.2|LIGHTGRAY|DASHED")
    cha.setParameter("XAXIS_LABELS","June|July|Aug.|Sept.|Oct.|Nov.|Dec.")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("LEGEND_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("SERIE_1","Products")
    cha.setParameter("SERIE_2","Services")
    cha.setParameter("SERIE_TYPE_1","BAR3D")
    cha.setParameter("SERIE_TYPE_2","BAR3D")
    cha.setParameter("SERIE_FONT_1","Arial|BOLD|10")
    cha.setParameter("SERIE_FONT_2","Arial|BOLD|10")
    cha.setParameter("SERIE_DATA_1","12|43|50|45|30|32|10")
    cha.setParameter("SERIE_DATA_2","-10|41|48|39|36|34|0")
    cha.setParameter("SERIE_BORDER_TYPE_1","RAISED")
    cha.setParameter("SERIE_BORDER_TYPE_2","RAISED")
    cha.setParameter("SERIE_BAR_STYLE_1","YELLOW")
    cha.setParameter("SERIE_BAR_STYLE_2","GREEN")
    cha.setParameter("BARCHART_BARSPACE","1")
    cha.setParameter("BARCHART3D_DEPTH","15")
    cha.setParameter("BARCHART3D_FULL_DEPTH","TRUE")
    cha.setParameter("BARCHART3D_BACK","WHITE")
    cha.setParameter("CHART_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("CHART_FILL","LIGHTGRAY")
    cha.setParameter("BACK_IMAGE",imagesDir+"back13.gif")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"BarChart3D.png")
  end
  
  def paintAreaChartTransparency()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()
    cha.setParameter("TITLECHART","Sales")
    cha.setParameter("XLABEL","Month")
    cha.setParameter("YLABEL","Million $")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","10")#
    cha.setParameter("TICK_INTERVALY","2")
    cha.setParameter("BOTTOM_MARGIN","0.3")
    cha.setParameter("XAXIS_LABELS","June\n2004|July\n2004|Aug.\n2004|Sept.\n2004|Oct.\n2004|Nov.\n2004|Dec.\n2004")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("LEGEND_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("SERIE_1","Products")
    cha.setParameter("SERIE_2","Services")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|8")
    cha.setParameter("SERIE_FONT_2","Arial|PLAIN|8")
    cha.setParameter("SERIE_DATA_1","32|84|50|60|76|76|93")
    cha.setParameter("SERIE_DATA_2","65|43|80|45|30|32|42")
    cha.setParameter("SERIE_STYLE_1","0.2|RED|LINE")
    cha.setParameter("SERIE_STYLE_2","0.2|BLUE|LINE")
    cha.setParameter("SERIE_FILL_1","RED")
    cha.setParameter("SERIE_FILL_2","BLUE|0.5")
    cha.setParameter("SERIE_POINT_1","true")
    cha.setParameter("SERIE_POINT_2","true")
    cha.setParameter("CHART_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("CHART_FILL","LIGHTGRAY")
    cha.setParameter("BACK_IMAGE",imagesDir+"back13.gif")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"AreaChartTransparency.png")

  end
  
  def paintCombinedChart()
    
	  cha=J4LChart::ChartLoader.new()
    cha.clearParams()

    cha.setParameter("TITLECHART","Sales")
    cha.setParameter("XLABEL","Month")
    cha.setParameter("YLABEL","Million $")
    cha.setParameter("Y2LABEL","Million EURO")
    cha.setParameter("YLABEL_VERTICAL","true")
    cha.setParameter("Y2LABEL_VERTICAL","true")
    cha.setParameter("Y2AXIS","true")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("Y2SCALE_MIN","0")
    cha.setParameter("YSCALE_MAX","100")
    cha.setParameter("Y2SCALE_MAX","50")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","10")
    cha.setParameter("BIG_TICK_INTERVALY2","10")
    cha.setParameter("XAXIS_GRID","0.2|WHITE|DASHED")
    cha.setParameter("YAXIS_GRID","0.2|WHITE|DASHED")
    cha.setParameter("XAXIS_LABELS","June|July|Aug.|Sept.|Oct.|Nov.|Dec.")
    cha.setParameter("XAXIS_VERTICAL_LABELS","true")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("LEGEND_VERTICAL","FALSE")
    cha.setParameter("LEGEND_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("SERIE_1","Products")
    cha.setParameter("SERIE_2","Services")
    cha.setParameter("SERIE_TYPE_1","BAR")
    cha.setParameter("SERIE_SECONDYAXIS_1","true")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|10")
    cha.setParameter("SERIE_FONT_2","Arial|PLAIN|10")
    cha.setParameter("SERIE_COLOR_1","RED")
    cha.setParameter("SERIE_COLOR_2","BLUE")
    cha.setParameter("SERIE_DATA_1","30|30|34|23|22|23")
    cha.setParameter("SERIE_DATA_2","83|70|95|70|52|42")
    cha.setParameter("SERIE_DATAX_2","1|2|3|4|5|6|7")
    cha.setParameter("SERIE_BAR_STYLE_1","RED")
    cha.setParameter("SERIE_STYLE_2","0.2|BLUE|LINE")
    cha.setParameter("SERIE_POINT_1","true")
    cha.setParameter("SERIE_POINT_2","true")
    cha.setParameter("SERIE_POINT_COLOR_1","RED")
    cha.setParameter("SERIE_POINT_COLOR_2","BLUE")
    cha.setParameter("BARCHART_BARWIDTH","20")
    cha.setParameter("LEGEND_POSITION","BOTTOM")
    cha.setParameter("LEGEND_MARGIN","0.12")
    cha.setParameter("CHART_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("CHART_FILL","YELLOW")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"CombinedChart.png")
  end
  
  def paintStackedAxis()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()


    cha.setParameter("TITLE_FONT","ARIAL|BOLD|18")
    cha.setParameter("XLABEL","Coffee Machine")
    cha.setParameter("YLABEL","Results")
    cha.setParameter("YLABEL_VERTICAL","true")
    cha.setParameter("Y_1AXIS","TRUE")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("Y_1SCALE_MIN","0")
    cha.setParameter("YSCALE_MAX","100")
    cha.setParameter("Y_1SCALE_MAX","20")
    cha.setParameter("TICK_INTERVALY","10")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","1")
    cha.setParameter("YAXIS_TICKATBASE","true")
    cha.setParameter("YAXIS_GRID","1|#A0A0A0|NORMAL")
    cha.setParameter("Y_1AXIS_GRID","1|#A0A0A0|NORMAL")
    cha.setParameter("GRIDY","true")
    cha.setParameter("GRIDY_1","true")
    cha.setParameter("XAXIS_LABELS","Acme\nplus|Pato\nexpress|Rowe|Acme\nsupreme")
    cha.setParameter("YAXIS_START_WITH_BIG_TICK","true")
    cha.setParameter("YAXIS_BAR_STYLE","BAR")
    cha.setParameter("Y_1AXIS_BAR_STYLE","BAR")
    cha.setParameter("YAXIS_FILLING","LIGHTSALMON")
    cha.setParameter("Y_1AXIS_FILLING","LIGHTBLUE")
    cha.setParameter("YAXIS_LABEL","Survey 2")
    cha.setParameter("Y_1AXIS_LABEL","Survey 1")
    cha.setParameter("YAXIS_STACK_ADDITIONAL","TRUE")
    cha.setParameter("XAXIS_DATE_FORMAT","%b")
    cha.setParameter("XAXIS_INITIAL_DATE","02/02/2005")
    cha.setParameter("LEGEND","FALSE")
    cha.setParameter("SERIE_1","survey1")
    cha.setParameter("SERIE_2","survey2")
    cha.setParameter("SERIE_TYPE_1","BAR")
    cha.setParameter("SERIE_SECONDARY_YAXIS_1","1")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|8")
    cha.setParameter("SERIE_FONT_2","Arial|PLAIN|8")
    cha.setParameter("SERIE_DATA_1","10|7|9|5")
    cha.setParameter("SERIE_DATA_2","60|73|59|45")
    cha.setParameter("SERIE_DATAX_2","1|2|3|4")
    cha.setParameter("SERIE_STYLE_1","LIGHTBLUE")
    cha.setParameter("SERIE_STYLE_2","2|LIGHTSALMON|NORMAL")
    cha.setParameter("BARCHART_BARWIDTH","20")
    cha.setParameter("LINECHART_BACK","WHITE")
    cha.setParameter("LEFT_MARGIN","0.20")
    cha.setParameter("TOP_MARGIN","0.2")
    cha.setParameter("BOTTOM_MARGIN","0.2")
    cha.setParameter("CHART_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("CHART_FILL","LIGHTYELLOW")

    c=cha.build(false,false)
    c.saveToFile(outputDir+"StackedAxis.png")
  end

  def paintLineChart3D()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()
    cha.setParameter("TITLECHART","Sales")
    cha.setParameter("XLABEL","Month")
    cha.setParameter("YLABEL","Million $")
    cha.setParameter("YLABEL_VERTICAL","true")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","10")
    cha.setParameter("XAXIS_GRID","0.2|LIGHTGRAY|DASHED")
    cha.setParameter("YAXIS_GRID","0.2|LIGHTGRAY|DASHED")
    cha.setParameter("XAXIS_LABELS","June|July|Aug.|Sept.|Oct.|Nov.|Dec.")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("LEGEND_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("SERIE_1","Products")
    cha.setParameter("SERIE_2","Services")
    cha.setParameter("SERIE_TYPE_1","LINE3D")
    cha.setParameter("SERIE_TYPE_2","LINE3D")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|8")
    cha.setParameter("SERIE_FONT_2","Arial|PLAIN|8")
    cha.setParameter("SERIE_COLOR_1","BLACK")
    cha.setParameter("SERIE_COLOR_2","BLACK")
    cha.setParameter("SERIE_DATA_1","40|25|30|35|20|22|32")
    cha.setParameter("SERIE_DATA_2","20|41|48|39|36|34|50")
    cha.setParameter("SERIE_STYLE_1","0.2|RED|LINE")
    cha.setParameter("SERIE_STYLE_2","0.2|BLUE|LINE")
    cha.setParameter("SERIE_FILL_1","RED")
    cha.setParameter("LINECHART3D_DEPTH","20")
    cha.setParameter("LINECHART3D_BACK","WHITE")
    cha.setParameter("LINECHART3D_BORDER","0.2|BLACK|LINE")
    cha.setParameter("CHART_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("CHART_FILL","LIGHTGRAY")
    cha.setParameter("BACK_IMAGE",imagesDir+"back16.gif")
    cha.setParameter("XAXIS_ROTATE_LABELS","-45")
    c=cha.build(false,false)
    c.saveToFile(outputDir+"LineChart3D.png")

  end

  def paintPieChart2D()

	  cha=J4LChart::ChartLoader.new()
    cha.clearParams()

    cha.setParameter("TITLECHART","Sales 2003")
    cha.setParameter("LEGEND","TRUE")
    cha.setParameter("SERIE_1","Pie")
    cha.setParameter("SERIE_TYPE_1","PIE")
    cha.setParameter("PIE_STYLE_1","RED")
    cha.setParameter("PIE_STYLE_2","BLUE")
    cha.setParameter("PIE_STYLE_3","GREEN")
    cha.setParameter("PIE_NAME_1","Products")
    cha.setParameter("PIE_NAME_2","Services")
    cha.setParameter("PIE_NAME_3","Other")
    cha.setParameter("PIE_LABEL_FORMAT","#VALUE# (#PERCENTAGE#)")
    cha.setParameter("SERIE_DATA_1","94|48|28")
    cha.setParameter("SERIE_FONT_1","ARIAL|12")
    cha.setParameter("SERIE_LABELS_1","Products|Services|Other")
    cha.setParameter("SERIE_TOGETHER_1","true|false|true")
    cha.setParameter("CHART_BORDER","0.2|BLACK|LINE")
    cha.setParameter("CHART_FILL","#FFCC00")
    cha.setParameter("LEGEND_BORDER","0.2|BLACK|LINE")
    cha.setParameter("LEGEND_VERTICAL","false")
    cha.setParameter("LEGEND_POSITION","TOP")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("PIECHART_3D","false")

    c=cha.build(false,false)
    c.saveToFile(outputDir+"PieChart2D.png")

  end

  def paintRadarChart()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()

    cha.setParameter("TITLECHART","Costs analysis")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("LEGEND_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("SERIE_1","Product A")
    cha.setParameter("SERIE_2","Product B")
    cha.setParameter("SERIE_TYPE_1","RADAR")
    cha.setParameter("SERIE_TYPE_2","RADAR")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|8")
    cha.setParameter("SERIE_FONT_2","Arial|PLAIN|8")
    cha.setParameter("SERIE_COLOR_1","BLACK")
    cha.setParameter("SERIE_COLOR_2","BLACK")
    cha.setParameter("SERIE_DATA_1","12|73|50|95")
    cha.setParameter("SERIE_DATA_2","20|41|60|10")
    cha.setParameter("SERIE_STYLE_1","0.2|BLUE|LINE")
    cha.setParameter("SERIE_STYLE_2","0.2|GREEN|LINE")
    cha.setParameter("SERIE_FILL_1","BLUE")
    cha.setParameter("SERIE_POINT_1","true")
    cha.setParameter("SERIE_POINT_2","true")
    cha.setParameter("SERIE_POINT_COLOR_1","BLUE")
    cha.setParameter("SERIE_POINT_COLOR_2","GREEN")
    cha.setParameter("RADARCHART_BACK","WHITE")
    cha.setParameter("RADARCHART_BORDER","0.2|BLACK|LINE")
    cha.setParameter("RADARCHART_FACTOR_COLOR","BLACK")
    cha.setParameter("RADARCHART_FACTOR_FONT","Arial|PLAIN|12")
    cha.setParameter("RADARCHART_FACTOR_MAX","100|100|100|100")
    cha.setParameter("RADARCHART_FACTOR_MIN","0|0|0|0")
    cha.setParameter("RADARCHART_FACTOR_NAMES","R & D|Distribution|Marketing|other")
    cha.setParameter("RADARCHART_GRID","0.2|GRAY|DASHED")
    cha.setParameter("RADARCHART_GRID_FONT","Arial|PLAIN|8")
    cha.setParameter("RADARCHART_GRID_FONT_COLOR","GRAY")
    cha.setParameter("RADARCHART_RADIUS","0.8")
    cha.setParameter("CHART_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("CHART_FILL","LIGHTGRAY")
    cha.setParameter("BACK_IMAGE",imagesDir+"back16.gif")
    c=cha.build(false,false)


    c.saveToFile(outputDir+"RadarChart.png")
  end

  def paintBarChart()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()
    cha.setParameter("TITLECHART","Sales")
    cha.setParameter("XLABEL","Month")
    cha.setParameter("YLABEL","Million $")
    cha.setParameter("XSCALE_MIN","0")
    cha.setParameter("XSCALE_MAX","5.5")
    cha.setParameter("YSCALE_MIN","-15")
    cha.setParameter("BIG_TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY","10")
    cha.setParameter("XAXIS_LABELS","June|July|Aug.|Sept.|Oct.|Nov.|Dec.")
    cha.setParameter("CERO_XAXIS","LINE")
    cha.setParameter("YAXIS_INTEGER","TRUE")
    cha.setParameter("SERIE_1","Products")
    cha.setParameter("SERIE_2","Services")
    cha.setParameter("SERIE_TYPE_1","BAR")
    cha.setParameter("SERIE_TYPE_2","BAR")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|8")
    cha.setParameter("SERIE_FONT_2","Arial|BOLD|8")
    cha.setParameter("BOTTOM_MARGIN","0.18")
    cha.setParameter("SERIE_DATA_2","-10|41|48|39|36")
    cha.setParameter("SERIE_BORDER_TYPE_1","RAISED")
    cha.setParameter("SERIE_BORDER_TYPE_2","RAISED")
    cha.setParameter("SERIE_BAR_STYLE_1","#00FF00")
    cha.setParameter("SERIE_BAR_STYLE_2","#0000FF")
    cha.setParameter("BARCHART_BARSPACE","1")
    cha.setParameter("LEFT_MARGIN","0.15")
    cha.setParameter("CHART_FILL","#FFCC00")
    cha.setParameter("SERIE_NEGATIVE_STYLE_2","RED")
    cha.setParameter("YLABEL_VERTICAL","TRUE")
    cha.setParameter("SERIE_DATA_1","12|43|50|45|30")
    cha.setParameter("SERIE_TIPS_1","12|43|50|45|30")
    cha.setParameter("SERIE_TIPS_2","-10|41|48|39|36")
    cha.setParameter("CHART_SHOW_TIPS","true")
    cha.setParameter("BARCHART_BARSPACE","5")

    c=cha.build(false,false)
    c.saveToFile(outputDir+"BarChart.png")

  end

  def paintBarsWithImages()
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()

    cha.setParameter("WIDTH","440")
    cha.setParameter("HEIGHT","300")
    cha.setParameter("TITLE_FONT","Dialog|BOLD|14")
    cha.setParameter("XLABEL","Number of days")
    cha.setParameter("XLABEL_FONT","Dialog|PLAIN|12")
    cha.setParameter("XLABEL_COLOR","#000000")
    cha.setParameter("XSCALE_MIN","0")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("YSCALE_MAX","3.8")
    cha.setParameter("BIG_TICK_INTERVALX","10")
    cha.setParameter("BIG_TICK_INTERVALY","1")
    cha.setParameter("XAXIS_GRID","1.0|#c0c0c0|DOTS")
    cha.setParameter("GRIDX","TRUE")
    cha.setParameter("YAXIS_LABELS","@image value='"+imagesDir+"rain.gif'@\\n\\nRainy|@image value='"+imagesDir+"sun.gif'@\\n\\nSunny|@image value='"+imagesDir+"ray.gif'@\\n\\nStormy")
    cha.setParameter("XAXIS_BAR_STYLE","BAR")
    cha.setParameter("YAXIS_BAR_STYLE","BAR")
    cha.setParameter("XAXIS_FILLING","#33cccc")
    cha.setParameter("YAXIS_FILLING","#33cccc")
    cha.setParameter("XAXIS_TEMPLATE","@background value='LIGHTYELLOW'@@position value='+0px,+5px'@@border value='1|BLACK|NORMAL'@ #value#")
    cha.setParameter("XAXIS_CLOSED","TRUE")
    cha.setParameter("YAXIS_CLOSED","TRUE")
    cha.setParameter("LEGEND","FALSE")
    cha.setParameter("LEGEND_FILL","WHITE")
    cha.setParameter("LEGEND_VERTICAL","FALSE")
    cha.setParameter("LEGEND_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("SERIE_1","Paris")
    cha.setParameter("SERIE_2","London")
    cha.setParameter("SERIE_TYPE_1","BAR")
    cha.setParameter("SERIE_TYPE_2","BAR")
    cha.setParameter("SERIE_FONT_1","Dialog|PLAIN|9")
    cha.setParameter("SERIE_FONT_2","Dialog|PLAIN|9")
    cha.setParameter("SERIE_LABEL_TEMPLATE_1","@background value='WHITE'@@border value='1|BLACK|NORMAL'@ #value#")
    cha.setParameter("SERIE_LABEL_TEMPLATE_2","@background value='WHITE'@@border value='1|BLACK|NORMAL' @ #value#")
    cha.setParameter("SERIE_DATA_1","12|43|50")
    cha.setParameter("SERIE_DATA_2","10|41|48")
    cha.setParameter("SERIE_BORDER_TYPE_1","RAISED")
    cha.setParameter("SERIE_BORDER_TYPE_2","RAISED")
    cha.setParameter("SERIE_BAR_STYLE_1","#0000ff;#00cccc;HORIZONTAL")
    cha.setParameter("SERIE_BAR_STYLE_2","#ff0000;#ffc800;HORIZONTAL")
    cha.setParameter("SERIE_NEEDLE_STYLE_1","3.0|#000000|NORMAL")
    cha.setParameter("SERIE_NEEDLE_STYLE_2","3.0|#000000|NORMAL")
    cha.setParameter("SERIE_NEEDLE_STYLE_3","3.0|#000000|NORMAL")
    cha.setParameter("BARCHART_VERTICAL","FALSE")
    cha.setParameter("BARCHART_BARSPACE","5")
    cha.setParameter("BARCHART_BACK","#ffff99")
    cha.setParameter("LEGEND_POSITION","RIGHT")
    cha.setParameter("LEFT_MARGIN","0.15")
    cha.setParameter("BOTTOM_MARGIN","0.15")
    cha.setParameter("CHART_BORDER","0.2|#000000|NORMAL")
    cha.setParameter("CHART_FILL","#ffffff")
    cha.setParameter("CHART_SHOW_TIPS","TRUE")
    cha.setParameter("CHART_TIPS_COLOR","#FFDC00")
    cha.setParameter("CHART_TIPS_FONT","Serif|ITALIC|10")
    cha.setParameter("CHART_NOTE1","@position value='85%,20%'@@rotation value='90'@@font value='Arial|BOLD|14'@Weather statistics")
    cha.setParameter("CHART_NOTE2","@position value='15%,12%'@@font value='Arial|BOLD|12'@@color value='RED'@London @color value='BLACK'@/ @color value='BLUE'@Paris")

    c=cha.build(false,false)
    c.saveToFile(outputDir+"BarsWithImages.png")
  end

  def paintCombinedChart2()
   
    cha=J4LChart::ChartLoader.new()
    cha.clearParams()

    cha.setParameter("TITLE"," Time based data")
    cha.setParameter("LEGEND","TRUE")
    cha.setParameter("LEGEND_POSITION","BOTTOM")
    cha.setParameter("LEGEND_VERTICAL","false")
    cha.setParameter("LEGEND_MARGIN","0.12")
    cha.setParameter("LEGEND_BORDER","1|BLACK|LINE")
    cha.setParameter("YLABEL","Pressure")
    cha.setParameter("XLABEL","Time")
    cha.setParameter("YLABEL_FONT","Verdana|PLAIN|10")
    cha.setParameter("Y2LABEL_VERTICAL","true")
    cha.setParameter("YLABEL_VERTICAL","true")
    cha.setParameter("Y2LABEL","Temperature")
    cha.setParameter("Y2LABEL_FONT","Verdana|PLAIN|10")
    cha.setParameter("SERIE_1","Factor A")
    cha.setParameter("SERIE_FONT_1","Arial|PLAIN|8")
    cha.setParameter("SERIE_FORMAT_1","#.0")
    cha.setParameter("SERIE_STYLE_1","3|#F5B549|LINE")
    cha.setParameter("SERIE_TYPE_1","LINE")
    cha.setParameter("SERIE_DATAX_1","1|2|3|4|5|6|7|8|9|10")
    cha.setParameter("SERIE_DATA_1","10|20|30|40|50|60|70|80|90|100")
    cha.setParameter("SERIE_DATA_2","15|25|15|35|50|66|10|50|40|10")
    cha.setParameter("SERIE_2","Measure")
    cha.setParameter("SERIE_TYPE_2","BAR")
    cha.setParameter("SERIE_STYLE_2","#EEEEEE")
    cha.setParameter("SERIE_FONT_2","NULL")
    cha.setParameter("SERIE_COLOR_2","BLACK")
    cha.setParameter("BARCHART_BARWIDTH","20")
    cha.setParameter("SERIE_SECONDYAXIS_2","TRUE")
    cha.setParameter("BIG_TICK_INTERVALY","1")
    cha.setParameter("TICK_INTERVALY","5")
    cha.setParameter("YSCALE_MIN","0")
    cha.setParameter("YSCALE_MAX","100")
    cha.setParameter("XSCALE_MAX","10")
    cha.setParameter("XAXIS_GRID","1|#DDDDDD|LINE")
    cha.setParameter("XAXIS_DATE_STEP","S")
    cha.setParameter("XAXIS_DATE_FORMAT","%H:%M:%S")
    cha.setParameter("XAXIS_INITIAL_DATE","02/02/2011 00:20:40")
    cha.setParameter("XAXIS_TICKATBASE","false")
    cha.setParameter("BIG_TICK_INTERVALX","2")
    cha.setParameter("TICK_INTERVALX","1")
    cha.setParameter("BIG_TICK_INTERVALY2","1")
    cha.setParameter("TICK_INTERVALY2","5")
    cha.setParameter("Y2SCALE_MIN","0")
    cha.setParameter("Y2SCALE_MAX","10")
    cha.setParameter("Y2AXIS","true")
    cha.setParameter("YAXIS_GRID","1|#DDDDDD|LINE")
    cha.setParameter("CHART_SECOND_AXIS_MARGIN","0")
    cha.setParameter("CHART_FILL","#FFFFFF")

    c=cha.build(false,false)
    c.saveToFile(outputDir+"CombinedChart2.png")
  end

end